==> FitGallery-0.70.tar.gz: FitGallery-0.70/ver_thumb.php <==
<?php

echo '<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01//EN"
      "http://www.w3.org/TR/html4/strict.dtd">
<!-- FitGallery copyleft GPL Pollo y Presi 0.70 -->
<html>
<head>
<style type="text/css">
<!--
div.figure
{
  float: left;  
  border: thin red solid;
  margin: 0.3em;
  padding: 0.3em;
  text-align: center;
}
p.caption
{
  font-size: smaller;
  text-indent: 0;
}
p.clear
{ 
  clear: left;
  text-align: center;
}
p.center,h3.center,h4.center
{ 
  text-align: center;
}
img.sinborde
{
  border-style: none;
}
a.texto
{
  color: #0000ff;
}

a.texto:visited       
{               
  color: #660066;
}               

a.texto:active
{
  color: #ff0000;
}

a.texto:hover
{
  color: #0000ff;
  background: #ffffcc;
}
body
{
';
if (mt_rand(0,1)) $c_r="d";
else $c_r="f";
if (mt_rand(0,1)) $c_g="d";
else $c_g="e";
if (mt_rand(0,1)) $c_b="d";
else $c_b="e";
echo '  background: #'.$c_r.'0'.$c_g.'0'.$c_b.'0; 
  color: #000000;
}
-->
</style>
<title>FitGallery 0.70</title>
</head>
<body>
<h3 class="center">FitGallery 0.70</h3>
';


$handle=opendir('imgs'); 
$n=0;
$total=0;
while ($file = readdir($handle))
{ 
 if ($file != "." && $file != "..")
  {
    $arr[$n][0]=filemtime("imgs/$file");
    $arr[$n][1]=$file;
    $arr[$n][2]=filesize("imgs/$file");
    $total += $arr[$n][2];
    $n++;
  }
}
closedir($handle); 

sort($arr);
$numero_arch=count($arr);

settype($para, "integer");
$para=$_GET["para"];
if ($para=='' || !is_numeric($para) || $para<0 || $para>$numero_arch) $para=0;
$para=intval($para);

$avance=12;                # numero de fotos que saldrn por pagina
$desde=$para+1;
$avmenosuno=$avance-1;
$hasta=$desde+$avmenosuno;
if ($hasta>$numero_arch) $hasta=$numero_arch;

echo "<h4 class=\"center\">$desde-$hasta</h4>\n";

$para2=$para+($avmenosuno);
$nummenosuno=$numero_arch-1;
if ($para2 >= $numero_arch) $para2 = $nummenosuno;
for ( $i=$para ; $i <= $para2 ; $i++) 
{
   $valor=$arr[$i][1];	
   $size=getimagesize("imgs/$valor");
   $bytes=$arr[$i][2];
   $fecha=date("d/m/Y H:i:s",$arr[$i][0]);

   echo "
   <div class=\"figure\">
   <a href=\"imgs/$valor\">
   <img class=\"sinborde\" src=\"thumb.php?valor=$valor\" alt=\"$valor\">
   </a>
   <p class=\"caption\">";
   echo $i+1;
   echo ". ";
   echo "<a class=\"texto\" href=\"imgs/$valor\">
   $valor<br>
   </a>
   $size[0]x$size[1]<br>
   $bytes bytes<br>
   $fecha
   </p>
   </div>
";
}

$numer_pag=$nummenosuno/$avance;
settype($numer_pag, "integer");

echo '
<p class="clear">
<br>
<strong>Galer&iacute;as: </strong>
';

for ($i = 1, $cuenta=$avance, $cuentaant=1; $i <= $numer_pag; $i++)
{
   $cuentaantmenosuno=$cuentaant-1;
   if ($cuentaant!=$desde) echo "<a class=\"texto\" href=\"ver_thumb.php?para=$cuentaantmenosuno\">";
   echo "$cuentaant-$cuenta";
   if ($cuentaant!=$desde) echo "</a>";
   echo " | ";
   $cuentaant=$cuenta+1;
   $cuenta=$cuenta+$avance;
}

$cuentaantmenosuno=$cuentaant-1;
$totalmegas=$total/10485.76;
$totalmegas=round($totalmegas)/100;
if ($cuentaant!=$desde) echo "<a class=\"texto\" href=\"ver_thumb.php?para=$cuentaantmenosuno\">";
echo "$cuentaant-$numero_arch";
if ($cuentaant!=$desde) echo "</a>";
echo '</p>
<p class="clear">
';
$anterior=$para-$avance;
$siguiente=$para+$avance;
if ($anterior<0) echo "Anterior";
            else echo "<a class=\"texto\" href=\"ver_thumb.php?para=$anterior\">Anterior</a>";
print " | ";
if ($siguiente>$cuentaantmenosuno) echo "Siguiente";
            else echo "<a class=\"texto\" href=\"ver_thumb.php?para=$siguiente\">Siguiente</a>";
echo "</p>
<p class=\"center\">
Total bytes: $total ($totalmegas MB)
</p>
<p class=\"center\">
<a href=\"http://validator.w3.org/check/referer\">
<img class=\"sinborde\" src=\"valid-html401.png\" alt=\"Valid HTML 4.01!\" height=\"31\" width=\"88\">
</a>
</p>
</body>
</html>";

?>

==> FitGallery-0.75.tar.gz: FitGallery-0.75/ver_thumb.php <==
<?php

$dirgal=".";  # directory when the gallery directories are
$galeria=basename($_GET["galeria"]);
$dirimgs="imgs";
$semiruta=$dirgal."/".$galeria;
$titulo="titulo";
$lineas=file($semiruta."/".$titulo);
$ruta=$semiruta."/".$dirimgs;
$n=0;
$total=0;


echo '<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01//EN"
      "http://www.w3.org/TR/html4/strict.dtd">
<!-- FitGallery 0.75 copyleft GPL Pollo (magura@ardilla.dyndns.org) y Presi (presi@confluencia.net) -->
<html>
<head>
<style type="text/css">
<!--
div.figure
{
  float: left;
  border: thin red solid;
  margin: 0.3em;
  padding: 0.3em;
  text-align: center;
}
p.caption
{
  font-size: smaller;
  text-indent: 0;
}
p.clear
{ 
  clear: left;
  text-align: center;
}
p.center,h3.center,h4.center
{ 
  text-align: center;
}
img.sinborde
{
  border-style: none;
}
a.texto
{
  color: #0000ff;
}

a.texto:visited       
{               
  color: #660066;
}               

a.texto:active
{
  color: #ff0000;
}

a.texto:hover
{
  color: #0000ff;
  background: #ffffcc;
}
body
{
';
if (mt_rand(0,1)) $c_r="d";
else $c_r="f";
if (mt_rand(0,1)) $c_g="d";
else $c_g="e";
if (mt_rand(0,1)) $c_b="d";
else $c_b="e";
echo '  background: #'.$c_r.'0'.$c_g.'0'.$c_b.'0; 
  color: #000000;
}
-->
</style>
<title>'.$lineas[0].'</title>
</head>
<body>
<h3 class="center">'.$lineas[0].'</h3>
';


$handle=opendir($ruta); 
while ($file = readdir($handle))
{ 
 if ($file != "." && $file != "..")
  {
    $arr[$n][0]=filemtime("$ruta/$file");
    $arr[$n][1]=$file;
    $arr[$n][2]=filesize("$ruta/$file");
    $total += $arr[$n][2];
    $n++;
  }
}
closedir($handle); 

sort($arr);
$numero_arch=count($arr);

settype($para, "integer");
$para=$_GET["para"];
if ($para=='' || !is_numeric($para) || $para<0 || $para>$numero_arch) $para=0;
$para=intval($para);

$avance=12;                # numero de fotos que saldrn por pagina
$desde=$para+1;
$avmenosuno=$avance-1;
$hasta=$desde+$avmenosuno;
if ($hasta>$numero_arch) $hasta=$numero_arch;

echo "<h4 class=\"center\">$desde-$hasta</h4>\n";

$para2=$para+($avmenosuno);
$nummenosuno=$numero_arch-1;
if ($para2 >= $numero_arch) $para2 = $nummenosuno;
for ( $i=$para ; $i <= $para2 ; $i++) 
{
   $valor=$arr[$i][1];	
   $size=getimagesize("$ruta/$valor");
   $bytes=$arr[$i][2];
   $fecha=date("d/m/Y H:i:s",$arr[$i][0]);

   echo "
   <div class=\"figure\">
   <a href=\"$ruta/$valor\">
   <img class=\"sinborde\" src=\"thumb.php?galeria=$galeria&amp;valor=$valor\" alt=\"$valor\">
   </a>
   <p class=\"caption\">";
   echo $i+1;
   echo ". ";
   echo "<a class=\"texto\" href=\"$ruta/$valor\">
   $valor<br>
   </a>
   $size[0]x$size[1]<br>
   $bytes bytes<br>
   $fecha
   </p>
   </div>
";
}

$numer_pag=$nummenosuno/$avance;
settype($numer_pag, "integer");

echo '
<p class="clear">
<br>
<strong>Galer&iacute;as: </strong>
';

for ($i = 1, $cuenta=$avance, $cuentaant=1; $i <= $numer_pag; $i++)
{
   $cuentaantmenosuno=$cuentaant-1;
   if ($cuentaant!=$desde) echo "<a class=\"texto\" href=\"ver_thumb.php?galeria=$galeria&amp;para=$cuentaantmenosuno\">";
   echo "$cuentaant-$cuenta";
   if ($cuentaant!=$desde) echo "</a>";
   echo " | ";
   $cuentaant=$cuenta+1;
   $cuenta=$cuenta+$avance;
}

$cuentaantmenosuno=$cuentaant-1;
$totalmegas=$total/10485.76;
$totalmegas=round($totalmegas)/100;
if ($cuentaant!=$desde) echo "<a class=\"texto\" href=\"ver_thumb.php?galeria=$galeria&amp;para=$cuentaantmenosuno\">";
echo "$cuentaant-$numero_arch";
if ($cuentaant!=$desde) echo "</a>";
echo '</p>
<p class="clear">
';
$anterior=$para-$avance;
$siguiente=$para+$avance;
if ($anterior<0) echo "Anterior";
            else echo "<a class=\"texto\" href=\"ver_thumb.php?galeria=$galeria&amp;para=$anterior\">Anterior</a>";
print " | ";
if ($siguiente>$cuentaantmenosuno) echo "Siguiente";
            else echo "<a class=\"texto\" href=\"ver_thumb.php?galeria=$galeria&amp;para=$siguiente\">Siguiente</a>";
echo "</p>
<p class=\"center\">
Total bytes: $total ($totalmegas MB)
</p>
<p class=\"center\">
<a href=\"http://validator.w3.org/check/referer\">
<img class=\"sinborde\" src=\"valid-html401.png\" alt=\"Valid HTML 4.01!\" height=\"31\" width=\"88\">
</a>
</p>
</body>
</html>";

?>
